@@ -294,6 +294,61 @@ update_revealer_visibility_cb (GtkRevealer *revealer)
     gtk_widget_set_visible (GTK_WIDGET (revealer), FALSE);
 }
 
+static void
+sync_datetimes (GcalEditDialog *self,
+                GParamSpec     *pspec,
+                GtkWidget      *widget)
+{
+  GDateTime *start, *end, *new_date;
+  GtkWidget *date_widget, *time_widget;
+  gboolean is_start;
+  gint hour_to_add;
+
+  is_start = (widget == self->start_time_selector || widget == self->start_date_selector);
+  start = gcal_edit_dialog_get_date_start (self);
+  end = gcal_edit_dialog_get_date_end (self);
+
+  /* The date is valid, no need to update the fields */
+  if (g_date_time_compare (end, start) >= 0)
+    goto out;
+
+  /*
+   * If the user is changing the start date or time, we change the end
+   * date or time (and vice versa).
+   */
+  hour_to_add = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->all_day_check)) ? 0 : 1;
+
+  if (is_start)
+    {
+      new_date = g_date_time_add_hours (start, hour_to_add);
+
+      date_widget = self->end_date_selector;
+      time_widget = self->end_time_selector;
+    }
+  else
+    {
+      new_date = g_date_time_add_hours (end, hour_to_add);
+
+      date_widget = self->start_date_selector;
+      time_widget = self->start_time_selector;
+    }
+
+  g_signal_handlers_block_by_func (date_widget, sync_datetimes, self);
+  g_signal_handlers_block_by_func (time_widget, sync_datetimes, self);
+
+  gcal_date_selector_set_date (GCAL_DATE_SELECTOR (date_widget), new_date);
+  gcal_time_selector_set_time (GCAL_TIME_SELECTOR (time_widget), new_date);
+
+  g_signal_handlers_unblock_by_func (date_widget, sync_datetimes, self);
+  g_signal_handlers_unblock_by_func (time_widget, sync_datetimes, self);
+
+  g_clear_pointer (&new_date, g_date_time_unref);
+
+out:
+  g_clear_pointer (&start, g_date_time_unref);
+  g_clear_pointer (&end, g_date_time_unref);
+}
+
 static void
 gcal_edit_dialog_get_property (GObject    *object,
                                guint       prop_id,
@@ -442,6 +497,7 @@ gcal_edit_dialog_class_init (GcalEditDialogClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, update_summary);
   gtk_widget_class_bind_template_callback (widget_class, update_location);
   gtk_widget_class_bind_template_callback (widget_class, update_revealer_visibility_cb);
+  gtk_widget_class_bind_template_callback (widget_class, sync_datetimes);
 }
 
 static void
@@ -595,6 +651,19 @@ gcal_edit_dialog_action_button_clicked (GtkWidget *widget,
       start_date = gcal_edit_dialog_get_date_start (dialog);
       end_date = gcal_edit_dialog_get_date_end (dialog);
 
+      /*
+       * The end date for multi-day events is exclusive, so we bump it by a day.
+       * This fixes the discrepancy between the end day of the event and how it
+       * is displayed in the month view. See bug 769300.
+       */
+      if (all_day)
+        {
+          GDateTime *fake_end_date = g_date_time_add_days (end_date, 1);
+
+          g_clear_pointer (&end_date, g_date_time_unref);
+          end_date = fake_end_date;
+        }
+
       gcal_event_set_date_start (dialog->event, start_date);
       gcal_event_set_date_end (dialog->event, end_date);
 
@@ -649,31 +718,35 @@ gcal_edit_dialog_all_day_changed (GtkWidget *widget,
 /*
  * Alarm related functions
  */
+
+#define OFFSET(x)             (G_STRUCT_OFFSET (GcalEditDialog, x))
+#define WIDGET_FROM_OFFSET(x) (G_STRUCT_MEMBER (GtkWidget*, self, x))
+
+struct
+{
+  gint minutes;
+  gint button_offset;
+} minutes_button[] = {
+    { 5,     OFFSET (five_minutes_button) },
+    { 10,    OFFSET (ten_minutes_button) },
+    { 30,    OFFSET (thirty_minutes_button) },
+    { 60,    OFFSET (one_hour_button) },
+    { 1440,  OFFSET (one_day_button) },
+    { 2880,  OFFSET (two_days_button) },
+    { 4320,  OFFSET (three_days_button) },
+    { 10080, OFFSET (one_week_button) }
+};
+
 static GtkWidget*
 get_row_fow_alarm_trigger_minutes (GcalEditDialog *self,
                                    gint            minutes)
 {
-  gint i;
-
-  struct
-  {
-    gint       minutes;
-    GtkWidget *button;
-  } minutes_button[] = {
-      { 5,     self->five_minutes_button },
-      { 10,    self->ten_minutes_button },
-      { 30,    self->thirty_minutes_button },
-      { 60,    self->one_hour_button },
-      { 1440,  self->one_day_button },
-      { 2880,  self->two_days_button },
-      { 4320,  self->three_days_button },
-      { 10080, self->one_week_button }
-  };
+  guint i;
 
   for (i = 0; i < G_N_ELEMENTS (minutes_button); i++)
     {
       if (minutes_button[i].minutes == minutes)
-        return minutes_button[i].button;
+        return WIDGET_FROM_OFFSET (minutes_button[i].button_offset);
     }
 
   return NULL;
@@ -849,22 +922,7 @@ static void
 setup_alarms (GcalEditDialog *self)
 {
   GList *alarms, *l;
-  gint i;
-
-  struct
-  {
-    gint       minutes;
-    GtkWidget *button;
-  } minutes_button[] = {
-      { 5,     self->five_minutes_button },
-      { 10,    self->ten_minutes_button },
-      { 30,    self->thirty_minutes_button },
-      { 60,    self->one_hour_button },
-      { 1440,  self->one_day_button },
-      { 2880,  self->two_days_button },
-      { 4320,  self->three_days_button },
-      { 10080, self->one_week_button }
-  };
+  guint i;
 
   gtk_widget_set_visible (self->alarms_listbox, gcal_event_has_alarms (self->event));
 
@@ -880,7 +938,7 @@ setup_alarms (GcalEditDialog *self)
    * and only make them insensitive when needed.
    */
   for (i = 0; i < G_N_ELEMENTS (minutes_button); i++)
-    gtk_widget_set_sensitive (minutes_button[i].button, TRUE);
+    gtk_widget_set_sensitive (WIDGET_FROM_OFFSET (minutes_button[i].button_offset), TRUE);
 
   for (l = alarms; l != NULL; l = l->next)
     {
@@ -898,7 +956,7 @@ setup_alarms (GcalEditDialog *self)
       for (i = 0; i < G_N_ELEMENTS (minutes_button); i++)
         {
           if (minutes_button[i].minutes == minutes)
-            gtk_widget_set_sensitive (minutes_button[i].button, FALSE);
+            gtk_widget_set_sensitive (WIDGET_FROM_OFFSET (minutes_button[i].button_offset), FALSE);
         }
 
       /* Add the row */
@@ -912,32 +970,16 @@ static void
 add_alarm_button_clicked (GtkWidget      *button,
                           GcalEditDialog *self)
 {
-  gint i, minutes;
-
-  struct
-  {
-    GtkWidget *button;
-    gint       minutes;
-  } button_minutes[] = {
-      { self->five_minutes_button,   5 },
-      { self->ten_minutes_button,    10 },
-      { self->thirty_minutes_button, 30 },
-      { self->one_hour_button,       60 },
-      { self->one_day_button,        1440 },
-      { self->two_days_button,       2880 },
-      { self->three_days_button,     4320 },
-      { self->one_week_button,       10080 },
-      { NULL, 0 }
-  };
+  guint i, minutes;
 
   /* Search for the button minute */
   minutes = 0;
 
-  for (i = 0; i < G_N_ELEMENTS (button_minutes); i++)
+  for (i = 0; i < G_N_ELEMENTS (minutes_button); i++)
     {
-      if (button_minutes[i].button == button)
+      if (WIDGET_FROM_OFFSET (minutes_button[i].button_offset) == button)
         {
-          minutes = button_minutes[i].minutes;
+          minutes = minutes_button[i].minutes;
           break;
         }
     }
@@ -974,13 +1016,10 @@ gcal_edit_dialog_set_time_format (GcalEditDialog *dialog,
 {
   g_return_if_fail (GCAL_IS_EDIT_DIALOG (dialog));
 
-  if (dialog->format_24h != use_24h_format)
-  {
-    dialog->format_24h = use_24h_format;
+  dialog->format_24h = use_24h_format;
 
-    gcal_time_selector_set_time_format (GCAL_TIME_SELECTOR (dialog->start_time_selector), dialog->format_24h);
-    gcal_time_selector_set_time_format (GCAL_TIME_SELECTOR (dialog->end_time_selector), dialog->format_24h);
-  }
+  gcal_time_selector_set_time_format (GCAL_TIME_SELECTOR (dialog->start_time_selector), dialog->format_24h);
+  gcal_time_selector_set_time_format (GCAL_TIME_SELECTOR (dialog->end_time_selector), dialog->format_24h);
 }
 
 void
@@ -1054,19 +1093,33 @@ gcal_edit_dialog_set_event (GcalEditDialog *dialog,
       date_start = all_day ? g_date_time_ref (date_start) : g_date_time_to_local (date_start);
 
       date_end = gcal_event_get_date_end (event);
-      date_end = all_day ? g_date_time_ref (date_end) : g_date_time_to_local (date_end);
+      /*
+       * This is subtracting what has been added in gcal_edit_dialog_action_button_clicked ().
+       * See bug 769300.
+       */
+      date_end = all_day ? g_date_time_add_days (date_end, -1) : g_date_time_to_local (date_end);
 
       /* date */
+      g_signal_handlers_block_by_func (dialog->end_date_selector, sync_datetimes, dialog);
+      g_signal_handlers_block_by_func (dialog->start_date_selector, sync_datetimes, dialog);
+
       gcal_date_selector_set_date (GCAL_DATE_SELECTOR (dialog->start_date_selector), date_start);
       gcal_date_selector_set_date (GCAL_DATE_SELECTOR (dialog->end_date_selector), date_end);
 
+      g_signal_handlers_unblock_by_func (dialog->start_date_selector, sync_datetimes, dialog);
+      g_signal_handlers_unblock_by_func (dialog->end_date_selector, sync_datetimes, dialog);
+
       /* time */
+      g_signal_handlers_block_by_func (dialog->end_time_selector, sync_datetimes, dialog);
+      g_signal_handlers_block_by_func (dialog->start_time_selector, sync_datetimes, dialog);
+
       gcal_time_selector_set_time (GCAL_TIME_SELECTOR (dialog->start_time_selector), date_start);
       gcal_time_selector_set_time (GCAL_TIME_SELECTOR (dialog->end_time_selector), date_end);
 
+      g_signal_handlers_unblock_by_func (dialog->start_time_selector, sync_datetimes, dialog);
+      g_signal_handlers_unblock_by_func (dialog->end_time_selector, sync_datetimes, dialog);
+
       /* all_day  */
-      gtk_widget_set_sensitive (dialog->start_time_selector, dialog->writable && !all_day);
-      gtk_widget_set_sensitive (dialog->end_time_selector, dialog->writable && !all_day);
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->all_day_check), all_day);
 
       /* location */
